# -*- coding: utf-8 -*-

##
## Copyright (C) 2005-2007 Ingeniweb
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

"""
Misc import steps for GenericSetup (see profiles/default/import-steps.xml)
$Id: ExFile.py 6229 2007-08-02 13:30:44Z glenfant $
"""
__docformat__ = 'restructuredtext'
__author__ = ''

from Products.CMFEditions.StandardModifiers import manage_addOMInsideChildrensModifier
from Products.PloneArticle.config import PROJECTNAME, PLONEARTICLE_TOOL

def setupTool(context):
    """ Create PloneArticleTool at site root """

    if context.readDataFile('plonearticle.txt') is None:
        return

    site = context.getSite()

    atool = getattr(site, PLONEARTICLE_TOOL, None)

    if atool is None:
        site.manage_addProduct[PROJECTNAME].manage_addTool('PloneArticleTool')
        atool = getattr(site, PLONEARTICLE_TOOL, None)
        atool.setVersionFromFS()

    numvers, version = atool.getVersion()
    if not numvers and not version:
        # we are reinstalling over an older version. Set to the first one from
        # which we can migrate
        atool.setInstanceVersion('3.2.99')

    return 'PloneArticleTool  created'


def setupModifier(context):
    """Add a modifier for PloneArticle for CMFEditions"""

    if context.readDataFile('plonearticle.txt') is None:
        return

    mod_id = 'PloneArticleModifier'
    portal_modifier = context.getSite().portal_modifier
    if mod_id in portal_modifier.objectIds():
        # We delete and recreate that modifier
        portal_modifier._delObject(mod_id)
    manage_addOMInsideChildrensModifier(portal_modifier, mod_id)
    modifier = getattr(portal_modifier, mod_id)
    modifier.edit(enabled=True, condition="python:meta_type == 'PloneArticle'")
    return "CMFEdition modifier for PloneArticle added"


def setupKupu(context):
    """Update kupu properties"""

    # Should be done by GS with kupu.xml but exportimport.py of kupu supports only full configuration

    if context.readDataFile('plonearticle.txt') is None:
        return

    site = context.getSite()
    ktool = getattr(site, 'kupu_library_tool', None)
    if ktool:

        kupu_resources = {
            'linkable': ('PloneArticle','ImageInnerContentProxy','FileInnerContentProxy'),
            'mediaobject': ('ImageInnerContentProxy',),
            'containsanchors': ('PloneArticle',),
            'collection': ('PloneArticle', 'InnerContentContainer')
            }

        for resource_type in ('linkable', 'mediaobject', 'containsanchors', 'collection'):
            new_types = list(ktool.getPortalTypesForResourceType(resource_type))
            for type_id in kupu_resources[resource_type]:
                if type_id in new_types:
                    continue
                new_types.append(type_id)
            new_resources = []
            new_resources.append({
                'old_type': resource_type,
                'resource_type': resource_type,
                'portal_types': new_types})
            ktool.updateResourceTypes(new_resources)
        return 'Kupu set for PloneArticle'
    else:
        return 'Kupu not installed'
